# unitorch.cli.models

## ClassificationOutputs

::: unitorch.cli.models.ClassificationOutputs

## ClassificationTargets

::: unitorch.cli.models.ClassificationTargets

## EmbeddingOutputs

::: unitorch.cli.models.EmbeddingOutputs

## GenerationOutputs

::: unitorch.cli.models.GenerationOutputs

## GenerationTargets

::: unitorch.cli.models.GenerationTargets

## LossOutputs

::: unitorch.cli.models.LossOutputs
